@@ -1,7 +1,7 @@
 context("civis_future")
 library(civis)
 library(future)
-library(mockery)
+library(testthat)
 
 mock_r_eval <- function(fut) {
   r_remote_eval <- parse(system.file("scripts", "r_remote_eval.R", package = "civis"))
@@ -10,14 +10,14 @@ mock_r_eval <- function(fut) {
   # this deletes the commandArgs lines, which can no longer be mocked.
   r_remote_eval[2:3] <- NULL
 
-  with_mock(
-    `civis::read_civis` = function(...) fut,
-    `civis::scripts_post_containers_runs_outputs` = function(...) NULL,
-    `civis::write_civis_file` = function(...) NULL,
-    eval(r_remote_eval),
-    unlink('r-object.rds'),
-    return(res)
+  local_mocked_bindings(
+    read_civis = function(...) fut,
+    scripts_post_containers_runs_outputs = function(...) NULL,
+    write_civis_file = function(...) NULL
   )
+  eval(r_remote_eval)
+  unlink('r-object.rds')
+  return(res)
 }
 
 test_that("r eval works", {
@@ -44,17 +44,17 @@ test_that("r eval works", {
 
 mock_run <- function(expr) {
   fut <- CivisFuture(expr)
-  with_mock(
-    `civis::write_civis_file` = function(...) 123,
-    `civis::upload_runner_script` = function(...) 1,
-    `civis::scripts_post_containers` = function(...) NULL,
-    `civis::scripts_post_containers_runs` = function(fut) NULL,
-    `civis::scripts_post_containers_runs_outputs` = function(...) NULL,
-    `civis::scripts_get_containers_runs` = function(...) list(state = "succeeded"),
-    `civis::read_civis` = function(...) mock_r_eval(fut),
-    `civis::fetch_logs` = function(...) list("a log"),
-    list(fut = run(fut), value = future::value(fut))
+  local_mocked_bindings(
+    write_civis_file = function(...) 123,
+    upload_runner_script = function(...) 1,
+    scripts_post_containers = function(...) NULL,
+    scripts_post_containers_runs = function(fut) NULL,
+    scripts_post_containers_runs_outputs = function(...) NULL,
+    scripts_get_containers_runs = function(...) list(state = "succeeded"),
+    read_civis = function(...) mock_r_eval(fut),
+    fetch_logs = function(...) list("a log")
   )
+  list(fut = run(fut), value = future::value(fut))
 }
 
 test_that("run and value work", {
@@ -68,17 +68,17 @@ test_that("run and value work", {
 
 mock_err <- function(expr) {
   fut <- CivisFuture(expr)
-  with_mock(
-    `civis::write_civis_file` = function(...) 123,
-    `civis::upload_runner_script` = function(...) 1,
-    `civis::scripts_post_containers` = function(...) NULL,
-    `civis::scripts_post_containers_runs` = function(...) list(containerId = 1, id = 2),
-    `civis::scripts_post_containers_runs_outputs` = function(...) NULL,
-    `civis::scripts_get_containers_runs` = function(id, run_id) list(state = "failed"),
-    `civis::fetch_output` = function(...) NULL,
-    `civis::fetch_logs` = function(...) list("error_log"),
-    list(fut = run(fut), value = future::value(fut))
+  local_mocked_bindings(
+    write_civis_file = function(...) 123,
+    upload_runner_script = function(...) 1,
+    scripts_post_containers = function(...) NULL,
+    scripts_post_containers_runs = function(...) list(containerId = 1, id = 2),
+    scripts_post_containers_runs_outputs = function(...) NULL,
+    scripts_get_containers_runs = function(id, run_id) list(state = "failed"),
+    fetch_output = function(...) NULL,
+    fetch_logs = function(...) list("error_log")
   )
+  list(fut = run(fut), value = future::value(fut))
 }
 
 test_that("run and value handle errors", {
@@ -107,18 +107,18 @@ test_that("CivisFuture has the right stuff", {
 })
 
 test_that("resolved", {
-  with_mock(
-    `civis::scripts_get_containers_runs` = function(...) list(state = "running"),
-    fut <- CivisFuture(quote(2 + 2)),
-    expect_false(resolved(fut))
+  local_mocked_bindings(
+    scripts_get_containers_runs = function(...) list(state = "running")
   )
+  fut <- CivisFuture(quote(2 + 2))
+  expect_false(resolved(fut))
 })
 
 test_that("cancel", {
   fut <- CivisFuture(quote(2 + 2))
-  with_mock(
-    `scripts_delete_containers_runs` = function(...) NULL,
-    cancel(fut)
+  local_mocked_bindings(
+    scripts_delete_containers_runs = function(...) NULL
   )
+  cancel(fut)
   expect_equal(fut$state, "cancelled")
 })
